@@ -39,7 +39,7 @@ int compare_regions(ulv *bufa, ulv *bufb, size_t count) {
     for (i = 0; i < count; i++, p1++, p2++) {
         if (*p1 != *p2) {
             if (use_phys) {
-                physaddr = physaddrbase + i;
+                physaddr = physaddrbase + (i * sizeof(ul));
                 fprintf(stderr, 
                         "FAILURE: 0x%08lx != 0x%08lx at physical address "
                         "0x%08lx.\n", 
@@ -47,7 +47,7 @@ int compare_regions(ulv *bufa, ulv *bufb, size_t count) {
             } else {
                 fprintf(stderr, 
                         "FAILURE: 0x%08lx != 0x%08lx at offset 0x%08lx.\n", 
-                        (ul) *p1, (ul) *p2, (ul) i);
+                        (ul) *p1, (ul) *p2, (ul) (i * sizeof(ul)));
             }
             /* printf("Skipping to next test..."); */
             r = -1;
@@ -80,7 +80,7 @@ int test_stuck_address(ulv *bufa, size_t count) {
         for (i = 0; i < count; i++, p1++) {
             if (*p1 != (((j + i) % 2) == 0 ? (ul) p1 : ~((ul) p1))) {
                 if (use_phys) {
-                    physaddr = physaddrbase + i;
+                    physaddr = physaddrbase + (i * sizeof(ul));
                     fprintf(stderr, 
                             "FAILURE: possible bad address line at physical "
                             "address 0x%08lx.\n", 
@@ -89,7 +89,7 @@ int test_stuck_address(ulv *bufa, size_t count) {
                     fprintf(stderr, 
                             "FAILURE: possible bad address line at offset "
                             "0x%08lx.\n", 
-                            (ul) i);
+                            (ul) (i * sizeof(ul)));
                 }
                 printf("Skipping to next test...\n");
                 fflush(stdout);
@@ -445,3 +445,81 @@ int test_bitflip_comparison(ulv *bufa, ulv *bufb, size_t count) {
     fflush(stdout);
     return 0;
 }
+
+#ifdef TEST_NARROW_WRITES    
+int test_8bit_wide_random(ulv* bufa, ulv* bufb, size_t count) {
+    u8v *p1, *t;
+    ulv *p2;
+    int attempt;
+    unsigned int b, j = 0;
+    size_t i;
+
+    putchar(' ');
+    fflush(stdout);
+    for (attempt = 0; attempt < 2;  attempt++) {
+        if (attempt & 1) {
+            p1 = (u8v *) bufa;
+            p2 = bufb;
+        } else {
+            p1 = (u8v *) bufb;
+            p2 = bufa;
+        }
+        for (i = 0; i < count; i++) {
+            t = mword8.bytes;
+            *p2++ = mword8.val = rand_ul();
+            for (b=0; b < UL_LEN/8; b++) {
+                *p1++ = *t++;
+            }
+            if (!(i % PROGRESSOFTEN)) {
+                putchar('\b');
+                putchar(progress[++j % PROGRESSLEN]);
+                fflush(stdout);
+            }
+        }
+        if (compare_regions(bufa, bufb, count)) {
+            return -1;
+        }
+    }
+    printf("\b \b");
+    fflush(stdout);
+    return 0;
+}
+
+int test_16bit_wide_random(ulv* bufa, ulv* bufb, size_t count) {
+    u16v *p1, *t;
+    ulv *p2;
+    int attempt;
+    unsigned int b, j = 0;
+    size_t i;
+
+    putchar( ' ' );
+    fflush( stdout );
+    for (attempt = 0; attempt < 2; attempt++) {
+        if (attempt & 1) {
+            p1 = (u16v *) bufa;
+            p2 = bufb;
+        } else {
+            p1 = (u16v *) bufb;
+            p2 = bufa;
+        }
+        for (i = 0; i < count; i++) {
+            t = mword16.u16s;
+            *p2++ = mword16.val = rand_ul();
+            for (b = 0; b < UL_LEN/16; b++) {
+                *p1++ = *t++;
+            }
+            if (!(i % PROGRESSOFTEN)) {
+                putchar('\b');
+                putchar(progress[++j % PROGRESSLEN]);
+                fflush(stdout);
+            }
+        }
+        if (compare_regions(bufa, bufb, count)) {
+            return -1;
+        }
+    }
+    printf("\b \b");
+    fflush(stdout);
+    return 0;
+}
+#endif
